﻿using System;
using System.IO;
using System.Text;


namespace FirstProgram
{
  public class Statements
  {
    public void LocalDeclaration()
    {
      //int x;
      //{
      //  int y;
      //  int x; // Error - x already defined
      //}
      //{
      //  int y; // OK - y not in scope
      //}
      //Console.WriteLine(y); // Error - y is out of scope
    }

    public void ExpressionStatement()
    {
      // Declare variables with declaration statements:
      string s;
      int x, y;
      System.Text.StringBuilder sb;

      x = 1 + 2;                // Assignment expression
      x++;                      // Increment expression
      y = Math.Max(x, 5);       // Assignment expression
      Console.WriteLine(y);     // Method call expression
      sb = new StringBuilder(); // Assignment expression
      new StringBuilder();      // Object instantiation expression

      new StringBuilder();      // Legal, but useless
      new string('c', 3);       // Legal, but useless
      x.Equals(y);              // Legal, but useless
    }

    public void SelectionStatements()
    {
      IfStatement();

      SwitchStatement(5);
    }

    public void IterationStatements()
    {
      While();
      DoWhile();
      For();
      Foreach();
    }

    public void JumpStatements()
    {
      Break();
      Continue();
      Goto();
      Return(5);
      Throw(null);
    }

    public void MiscellaneousStatements()
    {
      
      byte[] buffer = new byte[]{};
      int offset = 0;
      int count = 0;
       
      using (var file = File.Open(@"c.\Filepath.txt", FileMode.OpenOrCreate))
      {
        file.Write(buffer,offset,count);
      } // file.Dispose() is called here
    }

    private void IfStatement()
    {
      if (5 < 2 * 3)
      {
        Console.WriteLine("true"); // true
      }

      if (5 < 2 * 3)
      {
        Console.WriteLine("true");
        Console.WriteLine("Let's move on!");
      }
      else
      {
        Console.WriteLine("False"); // False        
      }

      if (2 + 2 == 5)
      {
        Console.WriteLine("Does not compute");
      }
      else
      {
        Console.WriteLine("False"); // False
      }
    }

    private void SwitchStatement(int cardNumber)
    {
      switch (cardNumber)
      {
        case 13:
          Console.WriteLine("King");
          break;
        case 12:
          Console.WriteLine("Queen");
          break;
        case 11:
          Console.WriteLine("Jack");
          break;
        case -1 : // Joker is −1
          goto case 12; // In this game joker counts as queen
        default: // Executes for any other cardNumber
          Console.WriteLine(cardNumber);
          break;
      }
    }

    private static void Throw(object obj)
    {
      if (obj == null)
      {
        throw new ArgumentNullException("obj");
      }
    }

    public decimal Return(decimal d)
    {
      decimal p = d * 100m;
      return p; // Return to the calling method with value
    }

    private static void Goto()
    {
      int i = 1;
      startLoop:
      if (i <= 5)
      {
        Console.Write(i + " ");
        i++;
        goto startLoop;
      }
    }

    private static void Continue()
    {
      for (int i = 0; i < 10; i++)
      {
        if ((i % 2) == 0) // If i is even,
        {
          continue; // continue with next iteration
        }
        Console.Write(i + " ");
      }
    }

    private static void Break()
    {
      int x = 0;
      while (true)
      {
        if (x++ > 5)
        {
          break; // break from the loop
        }
      }
      // execution continues here after break
    }

    private static void Foreach()
    {
      foreach (char c in "beer") // c is the iteration variable
      {
        Console.WriteLine(c);
      }
    }

    private static void For()
    {
      for (int i = 0, prevFib = 1, curFib = 1; i < 10; i++)
      {
        Console.WriteLine(prevFib);
        int newFib = prevFib + curFib;
        prevFib = curFib;
        curFib = newFib;
      }
    }

    private static void DoWhile()
    {
      int i = 0;
      do
      {
        Console.WriteLine(i);
        i++;
      } while (i < 3);
    }

    private static void While()
    {
      int i = 0;
      while (i < 3)
      {
        Console.WriteLine(i);
        i++;
      }
    }
  }
}
